
eduAlgo
======

A simple python module to use different algorithms in educational purposes.

Installation
------------

Fast install:

::

    pip install eduAlgo

Example
--------

```python

    from edualgo import algorithm.sort

    arr = [5,4,3,2,1]
    obj = sort()
    sorted_arr = obj.bubble_sort(arr)
    print(sorted_arr)
```



Here is the output:

[1,2,3,4,5]
